::: laktory.models.Grants

---

::: laktory.models.databricks.grants.Grant

--- 
Each grant model allows a set of privileges to a principal and operate on a securable object.
More details on privileges available [here](https://docs.databricks.com/en/sql/language-manual/sql-ref-privileges.html#privilege-types).


::: laktory.models.CatalogGrant

---

::: laktory.models.ConnectionGrant

---

::: laktory.models.ExternalLocationGrant

---

::: laktory.models.FunctionGrant

---

::: laktory.models.MetastoreGrant

---

::: laktory.models.RegisteredModelGrant

---

::: laktory.models.SchemaGrant

---

::: laktory.models.ShareGrant

---

::: laktory.models.StorageCredentialGrant

---

::: laktory.models.TableGrant

---

::: laktory.models.ViewGrant

---

::: laktory.models.VolumeGrant
